@@ -66,7 +66,7 @@ GSStyleManager <- R6Class("GSStyleManager",
     getStyles = function(){
       self$INFO("Fetching list of styles")
       req <- GSUtils$GET(self$getUrl(), private$user,
-                         keyring::key_get(service = private$keyring_service, username = private$user),
+                         private$keyring_backend$get(service = private$keyring_service, username = private$user),
                          "/styles.xml", self$verbose.debug)
       styleList <- NULL
       if(status_code(req) == 200){
@@ -100,7 +100,7 @@ GSStyleManager <- R6Class("GSStyleManager",
       }
       reqUrl <- paste0(reqUrl, sprintf("/styles/%s.xml", style))
       req <- GSUtils$GET(self$getUrl(), private$user,
-                         keyring::key_get(service = private$keyring_service, username = private$user),
+                         private$keyring_backend$get(service = private$keyring_service, username = private$user),
                          reqUrl, self$verbose.debug)
       style <- NULL
       if(status_code(req) == 200){
@@ -150,7 +150,7 @@ GSStyleManager <- R6Class("GSStyleManager",
       req <- GSUtils$POST(
         url = self$getUrl(),
         user = private$user,
-        pwd = keyring::key_get(service = private$keyring_service, username = private$user),
+        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
         path = reqUrl,
         content = as(sldBody, "character"),
         contentType = contentType,
@@ -201,7 +201,7 @@ GSStyleManager <- R6Class("GSStyleManager",
       updated <- FALSE
       req <- GSUtils$PUT(
         url = self$getUrl(), user = private$user,
-        pwd = keyring::key_get(service = private$keyring_service, username = private$user),
+        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
         path = reqUrl,
         content = as(sldBody, "character"),
         contentType = contentType,
@@ -232,7 +232,7 @@ GSStyleManager <- R6Class("GSStyleManager",
       #TODO hack for style removing (not managed by REST API) - check version
       
       req <- GSUtils$DELETE(self$getUrl(), private$user,
-                            keyring::key_get(service = private$keyring_service, username = private$user),
+                            private$keyring_backend$get(service = private$keyring_service, username = private$user),
                             path = path, self$verbose.debug)
       if(status_code(req) == 200){
         self$INFO("Successfully deleted style!")
@@ -266,7 +266,7 @@ GSStyleManager <- R6Class("GSStyleManager",
       }
       reqUrl <- paste0(reqUrl, sprintf("/styles/%s.sld", style))
       req <- GSUtils$GET(self$getUrl(), private$user,
-                         keyring::key_get(service = private$keyring_service, username = private$user),
+                         private$keyring_backend$get(service = private$keyring_service, username = private$user),
                          reqUrl, self$verbose.debug)
       style <- NULL
       if(status_code(req) == 200){
