@@ -77,7 +77,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
     getWorkspaces = function(){
       self$INFO("Fetching list of workspaces")
       req <- GSUtils$GET(self$getUrl(), private$user,
-                         keyring::key_get(service = private$keyring_service, username = private$user),
+                         private$keyring_backend$get(service = private$keyring_service, username = private$user),
                          "/workspaces.xml", self$verbose.debug)
       wsList <- NULL
       if(status_code(req) == 200){
@@ -106,7 +106,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
     getWorkspace = function(ws){
       self$INFO(sprintf("Fetching workspace '%s'", ws))
       req <- GSUtils$GET(self$getUrl(), private$user,
-                         keyring::key_get(service = private$keyring_service, username = private$user),
+                         private$keyring_backend$get(service = private$keyring_service, username = private$user),
                       sprintf("/workspaces/%s.xml", ws), self$verbose.debug)
       workspace <- NULL
       if(status_code(req) == 200){
@@ -131,7 +131,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
         req <- GSUtils$POST(
           url = self$getUrl(),
           user = private$user,
-          pwd = keyring::key_get(service = private$keyring_service, username = private$user),
+          pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
           path = "/workspaces",
           content = GSUtils$getPayloadXML(ws),
           contentType = "text/xml",
@@ -146,7 +146,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       }else{
         self$INFO("Delegating workspace creation to namespace manager")
         nsman <- GSNamespaceManager$new(self$getUrl(), private$user,
-                                        keyring::key_get(service = private$keyring_service, username = private$user),
+                                        private$keyring_backend$get(service = private$keyring_service, username = private$user),
                                         self$loggerType)
         created <- nsman$createNamespace(name, uri)
       }
@@ -162,7 +162,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
         workspace <- GSWorkspace$new(name = name)
         req <- GSUtils$PUT(
           url = self$getUrl(), user = private$user,
-          pwd = keyring::key_get(service = private$keyring_service, username = private$user),
+          pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
           path = sprintf("/workspaces/%s.xml", name),
           content = GSUtils$getPayloadXML(workspace),
           contentType = "application/xml",
@@ -177,7 +177,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       }else{
         self$INFO("Delegating workspace update to namespace manager")
         nsman <- GSNamespaceManager$new(self$getUrl(), private$user, 
-                                        keyring::key_get(service = private$keyring_service, username = private$user),
+                                        private$keyring_backend$get(service = private$keyring_service, username = private$user),
                                         self$loggerType)
         updated <- nsman$updateNamespace(name, uri)
       }
@@ -194,7 +194,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       #TODO hack for style removing (not managed by REST API)
       
       req <- GSUtils$DELETE(self$getUrl(), private$user,
-                            keyring::key_get(service = private$keyring_service, username = private$user),
+                            private$keyring_backend$get(service = private$keyring_service, username = private$user),
                          path = path, self$verbose.debug)
       if(status_code(req) == 200){
         self$INFO("Successfully deleted workspace!")
@@ -213,7 +213,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       }
       self$INFO(sprintf("Fetching settings for workspace '%s'", ws))
       req <- GSUtils$GET(self$getUrl(), private$user,
-                         keyring::key_get(service = private$keyring_service, username = private$user),
+                         private$keyring_backend$get(service = private$keyring_service, username = private$user),
                          sprintf("/workspaces/%s/settings.xml", ws), self$verbose.debug)
       workspaceSettings <- NULL
       if(status_code(req) == 200){
@@ -237,7 +237,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       req <- GSUtils$PUT(
         url = self$getUrl(),
         user = private$user,
-        pwd = keyring::key_get(service = private$keyring_service, username = private$user),
+        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
         path = sprintf("/workspaces/%s/settings.xml", ws),
         content = GSUtils$getPayloadXML(workspaceSettings),
         contentType = "application/xml",
@@ -262,7 +262,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       updated <- FALSE
       req <- GSUtils$PUT(
         url = self$getUrl(), user = private$user,
-        pwd = keyring::key_get(service = private$keyring_service, username = private$user),
+        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
         path = sprintf("/workspaces/%s/settings.xml", ws),
         content = GSUtils$getPayloadXML(workspaceSettings),
         contentType = "application/xml",
@@ -287,7 +287,7 @@ GSWorkspaceManager <- R6Class("GSWorkspaceManager",
       deleted <- FALSE
       path <- sprintf("/workspaces/%s/settings", ws)
       req <- GSUtils$DELETE(self$getUrl(), private$user,
-                            keyring::key_get(service = private$keyring_service, username = private$user),
+                            private$keyring_backend$get(service = private$keyring_service, username = private$user),
                             path = path, self$verbose.debug)
       if(status_code(req) == 200){
         self$INFO("Successfully deleted workspace settings!")
